@@ -33,32 +33,35 @@ DJANGO_GENERATED_METHODS = [
     'validate_unique'
 ]
 
+
 class InspectModel(object):
 
-    def __init__(self, model, follow_relations=False):
+    def __init__(self, model):
         self.model = model
         if not inspect.isclass(model):
             self.model = model.__class__
 
-        self.fields = [] # standard django model fields
-        self.relation_fields = [] # OneToOne or ForeignKey fields
-        self.many_fields = [] # ManyToMany fields
-        self.attributes = [] # standard python class attributes
-        self.methods = [] # standard python class methods
-        self.items = [] # groups all of the above for convenience
+        self.fields = []  # standard django model fields
+        self.relation_fields = []  # OneToOne or ForeignKey fields
+        self.many_fields = []  # ManyToMany fields
+        self.attributes = []  # standard python class attributes
+        self.methods = []  # standard python class methods
+        self.items = []  # groups all of the above for convenience
+        self.properties = []  # properties
 
-        self.update_fields(follow_relations)
+        self.update_fields()
         self.update_attributes()
         self.update_methods()
+        self.update_properties()
 
-    def update_fields(self, follow_relations=False):
+    def update_fields(self):
         """Set the list of django.db.models fields
-        
+
         Three different types of fields:
         * standard model fields: Char, Integer...
         * relation fields: OneToOne (back and forth) and ForeignKey
         * many fields: ManyToMany (back and forth)
-        
+
         """
         self.fields = []
         self.relation_fields = []
@@ -68,25 +71,20 @@ class InspectModel(object):
             for f in opts.get_all_field_names():
                 field, model, direct, m2m = opts.get_field_by_name(f)
                 name = field.name
-                """
-                if direct: # field from this model
-                    if field.rel:
-                        pass
-                """
-                if not direct: # relation or many field from another model
+                if not direct:  # relation or many field from another model
                     name = field.get_accessor_name()
                     field = field.field
-                    if field.rel.multiple: # m2m or fk to this model
+                    if field.rel.multiple:  # m2m or fk to this model
                         self.add_item(name, self.many_fields)
-                    else: # o2o
+                    else:  # one to one
                         self.add_item(name, self.relation_fields)
-                else: # relation, many or field from this model
-                    if field.rel: # relation or many field
-                        if hasattr(field.rel, 'through'): # m2m
+                else:  # relation, many or field from this model
+                    if field.rel:  # relation or many field
+                        if hasattr(field.rel, 'through'):  # m2m
                             self.add_item(name, self.many_fields)
                         else:
                             self.add_item(name, self.relation_fields)
-                    else: # standard field
+                    else:  # standard field
                         self.add_item(name, self.fields)
 
     def update_attributes(self):
@@ -117,6 +115,13 @@ class InspectModel(object):
             if is_method_without_args(getattr(self.model, m, None)):
                 self.add_item(m, self.methods)
 
+    def update_properties(self):
+        """Return the list of properties"""
+        self.properties = []
+        for name in dir(self.model):
+            if isinstance(getattr(self.model, name, None), property):
+                self.add_item(name, self.properties)
+
     def add_item(self, item, item_type):
         item_type.append(item)
         # we only want each item once
@@ -124,12 +129,12 @@ class InspectModel(object):
         s.add(item)
         self.items = list(sorted(s))
 
+
 def is_method_without_args(func):
     """Check if func is a method callable with only one param (self)"""
-    if not inspect.ismethod(func):
+    if not inspect.isfunction(func) and not inspect.ismethod(func):
         return False
     args, var, named, defaults = inspect.getargspec(func)
     if defaults:
-        args = args[:-len(defaults)] # args with defaults don't count
+        args = args[:-len(defaults)]  # args with defaults don't count
     return len(args) == 1
-
